@@ -13,11 +13,10 @@ class ArgsValidator(_plotly_utils.basevalidators.InfoArrayValidator):
             items=kwargs.pop(
                 "items",
                 [
-                    {"valType": "any", "editType": "arraydraw"},
-                    {"valType": "any", "editType": "arraydraw"},
-                    {"valType": "any", "editType": "arraydraw"},
+                    {"editType": "arraydraw", "valType": "any"},
+                    {"editType": "arraydraw", "valType": "any"},
+                    {"editType": "arraydraw", "valType": "any"},
                 ],
             ),
-            role=kwargs.pop("role", "info"),
             **kwargs
         )
